<?php

namespace AppBundle\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Film
 *
 * @ORM\Table(name="film")
 * @ORM\Entity(repositoryClass="AppBundle\Repository\FilmRepository")
 */
class Film
{
    /**
     * @var int
     *
     * @ORM\Column(name="id", type="integer")
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="AUTO")
     */
    private $id;

    /**
     * @var string
     *
     * @ORM\Column(name="titre", type="string", length=255)
     */
    private $titre;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="annee", type="date", nullable=true)
     */
    private $annee;

    /**
     * @ORM\ManyToMany(targetEntity="AppBundle\Entity\Realisateur", inversedBy="films", cascade="persist")
     * @var \Doctrine\Common\Collections\Collection
     */
    private $realisateurs;

    /**
     * @ORM\ManyToOne(targetEntity="AppBundle\Entity\User")
     * @ORM\JoinColumn(nullable=false)
     */
    private $authered;

    /**
     * @ORM\ManyToMany(targetEntity="AppBundle\Entity\User")
     * @var \Doctrine\Common\Collections\Collection
     */
    private $usersWantToView;

    /**
     * @return mixed
     */
    public function getAuthered()
    {
        return $this->authered;
    }

    /**
     * @param mixed $authered
     */
    public function setAuthered($authered)
    {
        $this->authered = $authered;
        $authered->addFilm($this);
    }

    /**
     * Get id
     *
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * Set titre
     *
     * @param string $titre
     *
     * @return Film
     */
    public function setTitre($titre)
    {
        $this->titre = $titre;

        return $this;
    }

    /**
     * Get titre
     *
     * @return string
     */
    public function getTitre()
    {
        return $this->titre;
    }

    /**
     * Set annee
     *
     * @param \DateTime $annee
     *
     * @return Film
     */
    public function setAnnee($annee)
    {
        $this->annee = $annee;

        return $this;
    }

    /**
     * Get annee
     *
     * @return \DateTime
     */
    public function getAnnee()
    {
        return $this->annee;
    }

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->realisateurs = new \Doctrine\Common\Collections\ArrayCollection();
        $this->usersWantToView = new \Doctrine\Common\Collections\ArrayCollection();
    }

    /**
     * Add film
     *
     * @param \AppBundle\Entity\Film $film
     *
     * @return Realisateurs
     */
    public function addRealisateur(\AppBundle\Entity\Realisateur $realisateur)
    {
        $this->realisateurs[] = $realisateur;

        return $this;
    }

    /**
     * Remove film
     *
     * @param \AppBundle\Entity\Film $film
     */
    public function removeRealisateur(\AppBundle\Entity\Realisateur $realisateur)
    {
        $this->realisateurs->removeElement($realisateur);
    }

    /**
     * Get realisateurs
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getRealisateurs()
    {
        return $this->realisateurs;
    }


    ///////////////////////////////////////////////////////
    /**
     * Add user
     *
     * @param \AppBundle\Entity\User $user
     *
     * @return film
     */
    public function addUserWantToView(\AppBundle\Entity\User $user)
    {
        $this->usersWantToView[] = $user;
        $user->addFilm($this);

        return $this;
    }

    /**
     * Remove user
     *
     * @param \AppBundle\Entity\User $user
     */
    public function removeUserWantToView(\AppBundle\Entity\User $user)
    {
        $this->usersWantToView->removeElement($user);
        $user->removeFilm($this);
    }

    /**
     * Get usersWantToView
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getUsersWantToView()
    {
        return $this->usersWantToView;
    }

    /**
     * Inverse ToSee
     * @param \AppBundle\Entity\User $user
     */
    public function inverseUserWantToView(\AppBundle\Entity\User $user)
    {
        if ($this->usersWantToView->contains($user)) {
            $this->removeUserWantToView($user);
        } else {
            $this->addUserWantToView($user);
        }

    }

}
